#!/bin/bash

set -e

# get the root of the git repository
GIT_ROOT=$(git rev-parse --show-toplevel)
cd "$GIT_ROOT"

source generation/00env.sh

nproc=32

mkdir -p "$KERNEL_COMPILATION_DIR" && cd "$KERNEL_COMPILATION_DIR"
if [ ! -f linux-"$KERNEL_VERSION".tar.xz ]; then
	wget https://cdn.kernel.org/pub/linux/kernel/v5.x/linux-"$KERNEL_VERSION".tar.xz
fi
if [ ! -d linux-"$KERNEL_VERSION" ]; then
	tar -xaf linux-"$KERNEL_VERSION".tar.xz
fi
cd linux-"$KERNEL_VERSION"

if [ -f "$GIT_ROOT"/generation/config ]; then
	cp "$GIT_ROOT"/generation/config .config
else
	make olddefconfig

	./scripts/config \
		-d CONFIG_MODULE_SIG_ALL \
		-d CONFIG_MODULE_SIG_KEY \
		-d CONFIG_SYSTEM_TRUSTED_KEYS \
		-d CONFIG_DEBUG_INFO \
		-m CONFIG_NLS_CODEPAGE_437 \
		-m CONFIG_MSDOS_FS \
		-m CONFIG_NTFS_FS
		#-d ASHMEM \
		#-d ANDROID_BINDER_IPC
		#-e CONFIG_EFI_STUB

	cp .config .config.backup
	# tmp
	#sed -i "s/CONFIG_EXT4_FS=m/CONFIG_EXT4_FS=y/g" .config
	# embed all "iscsi"/"scsi"-related modules in the kernel
	#sed -i 's/CONFIG_\(.*\)SCSI\(.*\)=m/CONFIG_\1SCSI\2=y/g' .config
	# embed all "fat" and "vfat"-related modules in the kernel
	sed -i 's/CONFIG_\(.*\)FAT\(.*\)=y/CONFIG_\1FAT\2=m/g' .config
	# embed every modules in the kernel
	#sed -i 's/=m$/=y/g' .config

	make menuconfig # keep the options consistent: manually choose exit immediately
fi

make deb-pkg -j"$(nproc)" LOCALVERSION=-"$(dpkg --print-architecture)" KDEB_PKGVERSION="$(make kernelversion)-1"
cd ..
dpkg -x linux-image-"$KERNEL_VERSION"-amd64_"$KERNEL_VERSION"-1_amd64.deb "$KERNEL_DIR"
